@@ -1,8 +1,20 @@
+from __future__ import annotations
+
+import functools
 import itertools
 import random
-from typing import Any, Dict, List, Sequence, Tuple, TypeVar
+import typing as ty
+from abc import ABC, abstractmethod
+from collections import OrderedDict
+from dataclasses import dataclass
+from os import PathLike
+from typing import (Any, Dict, FrozenSet, Generic, List, Mapping, Optional,
+                    Sequence, Tuple, TypeVar, Union)
 
-import numpy as np  # type: ignore
+import instancelib as il
+import matplotlib.pyplot as plt  # type: ignore
+import numpy as np
+import pandas as pd
 from instancelib.feature_extraction.base import BaseVectorizer
 from instancelib.functions.vectorize import vectorize
 from instancelib.instances.base import Instance
@@ -14,8 +26,9 @@ from ..factory.factory import ObjectFactory
 from ..module.component import Component
 from ..stopcriterion.base import AbstractStopCriterion
 from ..typehints import DT, IT, KT, LT, RT, VT
+from .experiments import ExperimentIterator
 from .initialization import Initializer
-from .plotter import AbstractPlotter
+from .plotter import AbstractPlotter, ExperimentPlotter
 
 
 def reset_environment(vectorizer: BaseVectorizer[IT], 
@@ -74,6 +87,50 @@ def initialize(factory: ObjectFactory,
     learner = initializer(learner)
     return learner, vectorizer
 
+class TarSimulator(Generic[IT, KT, DT, VT, RT, LT]):
+    plotter: ExperimentPlotter[LT]
+    experiment: ExperimentIterator
+
+    def __init__(self, experiment: ExperimentIterator[IT, KT, DT, VT, RT, LT], 
+                       plotter: ExperimentPlotter[LT],
+                       max_it: Optional[int]=None,
+                       print_enabled = False) -> None:
+        self.experiment = experiment
+        self.plotter = plotter
+        self.max_it = max_it
+        self.print_enabled = print_enabled
+    
+    @property
+    def _debug_finished(self) -> bool:
+        if self.max_it is None:
+            return False
+        return self.experiment.it > self.max_it
+     
+    def simulate(self) -> None:
+        while not self.experiment.finished and not self._debug_finished:
+            result = self.experiment()
+            self.plotter.update(self.experiment, result)
+            if self.print_enabled:
+                self.plotter.print_last_stats()
+
+        
+
+
+
+
+
+
+
+        
+
+
+
+    
+   
+
+
+
+
 
 def simulate(learner: ActiveLearner[IT, KT, DT, VT, RT, LT],
              stop_crit: AbstractStopCriterion[LT],
