@@ -9,6 +9,8 @@ class ALConfiguration(Enum):
     RaschRF = "RaschRF"
     EntropySamplingNB = "EntropySamplingNB"
     ProbabilityEnsemble = "ProbabilityEnsemble"
+    RaschNBLRRF = "RaschNBLRRF"
+    RaschNBLRRFSVM = "RaschNBLRRFSVM"
 
 class FEConfiguration(Enum):
     TFIDF5000 = "TfIDF5000"
